function RUNME(long)

if( nargin<1 )
   long=false;
end

fname = 'abm_solution.mat';

if( exist(fname, 'file') )
   disp('loading solution');

   load(fname);

   int_func = @(t, y) (t-a)/(b-a)*A1*y + (b-t)/(b-a)*A2*y;

   disp('done');
else
   n=100;

   a = 0;
   b = 3;

   es = -linspace(0, 10, n);
   [Q, R] = qr(randn(n));
   A1 = Q' * diag(es) * Q;
   [Q, R] = qr(randn(n));
   A2 = Q' * diag(es) * Q;

   int_func = @(t, y) (t-a)/(b-a)*A1*y + (b-t)/(b-a)*A2*y;

   y0 = randn(n, 1);

   opts = odeset('RelTol', 1e-20, 'AbsTol', 1e-36);
   [times, sols] = ode45(int_func, [a, b], y0, opts);
   times = times'; sols = sols';
   sol = sols(:,end);

   save(fname, 'A1', 'A2', 'a', 'b', 'y0', 'sol');
end

if( long )
   max_step = 1000;
else
   max_step = 100;
end

steps = round(exp(log(10):0.1:log(max_step)));
errors = zeros(size(steps));

for ind_h=1:length(steps)
   n = steps(ind_h);

   [ab_times, ab_sols] = adams_bashforth(n, a, b, int_func, y0);

   errors(ind_h) = norm(ab_sols(:, end) - sol);
end

loglog(1./steps, errors, 'k-')
xlabel('Schrittweite');
ylabel('Fehler');

title('Das 3-schrittige Adams-Bashforth-Verfahren');
